==> saga_2.0.8+dfsg.orig.tar.gz: saga-2.0.8/src/modules_images/modules_vigra/vigra/MLB_Interface.cpp <==
/**********************************************************
 * Version $Id: MLB_Interface.cpp 911 2011-02-14 16:38:15Z reklov_w $
 *********************************************************/

///////////////////////////////////////////////////////////
//                                                       //
//                         SAGA                          //
//                                                       //
//      System for Automated Geoscientific Analyses      //
//                                                       //
//                    Module Library:                    //
//                        VIGRA                          //
//                                                       //
//-------------------------------------------------------//
//                                                       //
//                   MLB_Interface.cpp                   //
//                                                       //
//                 Copyright (C) 2009 by                 //
//                      Olaf Conrad                      //
//                                                       //
//-------------------------------------------------------//
//                                                       //
// This file is part of 'SAGA - System for Automated     //
// Geoscientific Analyses'. SAGA is free software; you   //
// can redistribute it and/or modify it under the terms  //
// of the GNU General Public License as published by the //
// Free Software Foundation; version 2 of the License.   //
//                                                       //
// SAGA is distributed in the hope that it will be       //
// useful, but WITHOUT ANY WARRANTY; without even the    //
// implied warranty of MERCHANTABILITY or FITNESS FOR A  //
// PARTICULAR PURPOSE. See the GNU General Public        //
// License for more details.                             //
//                                                       //
// You should have received a copy of the GNU General    //
// Public License along with this program; if not,       //
// write to the Free Software Foundation, Inc.,          //
// 59 Temple Place - Suite 330, Boston, MA 02111-1307,   //
// USA.                                                  //
//                                                       //
//-------------------------------------------------------//
//                                                       //
//    e-mail:     oconrad@saga-gis.org                   //
//                                                       //
//    contact:    Olaf Conrad                            //
//                Institute of Geography                 //
//                University of Hamburg                  //
//                Germany                                //
//                                                       //
///////////////////////////////////////////////////////////

//---------------------------------------------------------


///////////////////////////////////////////////////////////
//														 //
//			The Module Link Library Interface			 //
//														 //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
// 1. Include the appropriate SAGA-API header...

#include "MLB_Interface.h"


//---------------------------------------------------------
// 2. Place general module library informations here...

const SG_Char * Get_Info(int i)
{
	switch( i )
	{
	case MLB_INFO_Name:	default:
		return( _TL("Imagery - ViGrA") );

	case MLB_INFO_Author:
		return( _TL("O. Conrad (c) 2009") );

	case MLB_INFO_Description:
		return( _TW(
			"ViGrA stands for \"Vision with Generic Algorithms\". "
			"It's a novel computer vision library that puts its main "
			"emphasize on customizable algorithms and data structures. "
			"By using template techniques similar to those in the C++ "
			"Standard Template Library, you can easily adapt any VIGRA "
			"component to the needs of your application, without thereby "
			"giving up execution speed.\n"
			"Find out more at the ViGrA - Vision with Generic Algorithms - homepage:\n"
			"<a target=\"_blank\" href=\"http://hci.iwr.uni-heidelberg.de/vigra\">"
			"http://hci.iwr.uni-heidelberg.de</a>"
		));

	case MLB_INFO_Version:
		return( SG_T("1.0") );

	case MLB_INFO_Menu_Path:
		return( _TL("Imagery|ViGrA") );
	}
}


//---------------------------------------------------------
// 3. Include the headers of your modules here...

#include "vigra_smoothing.h"
#include "vigra_edges.h"
#include "vigra_morphology.h"
#include "vigra_distance.h"
#include "vigra_fft.h"
#include "vigra_watershed.h"


//---------------------------------------------------------
// 4. Allow your modules to be created here...

CSG_Module *		Create_Module(int i)
{
	switch( i )
	{
	case  0:	return( new CViGrA_Smoothing );
	case  1:	return( new CViGrA_Edges );
	case  2:	return( new CViGrA_Morphology );
	case  3:	return( new CViGrA_Distance );
	case  4:	return( new CViGrA_Watershed );
	case  5:	return( new CViGrA_FFT );
	case  6:	return( new CViGrA_FFT_Inverse );
	case  7:	return( new CViGrA_FFT_Real );
	case  8:	return( new CViGrA_FFT_Filter );
	}

	return( NULL );
}


///////////////////////////////////////////////////////////
//														 //
//														 //
//														 //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
//{{AFX_SAGA

	MLB_INTERFACE

//}}AFX_SAGA

==> saga_2.1.0+dfsg.orig.tar.gz: saga-2.1.0+dfsg/src/modules_images/modules_vigra/vigra/MLB_Interface.cpp <==
/**********************************************************
 * Version $Id: MLB_Interface.cpp 1246 2011-11-25 13:42:38Z oconrad $
 *********************************************************/

///////////////////////////////////////////////////////////
//                                                       //
//                         SAGA                          //
//                                                       //
//      System for Automated Geoscientific Analyses      //
//                                                       //
//                    Module Library:                    //
//                        VIGRA                          //
//                                                       //
//-------------------------------------------------------//
//                                                       //
//                   MLB_Interface.cpp                   //
//                                                       //
//                 Copyright (C) 2009 by                 //
//                      Olaf Conrad                      //
//                                                       //
//-------------------------------------------------------//
//                                                       //
// This file is part of 'SAGA - System for Automated     //
// Geoscientific Analyses'. SAGA is free software; you   //
// can redistribute it and/or modify it under the terms  //
// of the GNU General Public License as published by the //
// Free Software Foundation; version 2 of the License.   //
//                                                       //
// SAGA is distributed in the hope that it will be       //
// useful, but WITHOUT ANY WARRANTY; without even the    //
// implied warranty of MERCHANTABILITY or FITNESS FOR A  //
// PARTICULAR PURPOSE. See the GNU General Public        //
// License for more details.                             //
//                                                       //
// You should have received a copy of the GNU General    //
// Public License along with this program; if not,       //
// write to the Free Software Foundation, Inc.,          //
// 59 Temple Place - Suite 330, Boston, MA 02111-1307,   //
// USA.                                                  //
//                                                       //
//-------------------------------------------------------//
//                                                       //
//    e-mail:     oconrad@saga-gis.org                   //
//                                                       //
//    contact:    Olaf Conrad                            //
//                Institute of Geography                 //
//                University of Hamburg                  //
//                Germany                                //
//                                                       //
///////////////////////////////////////////////////////////

//---------------------------------------------------------


///////////////////////////////////////////////////////////
//														 //
//			The Module Link Library Interface			 //
//														 //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
// 1. Include the appropriate SAGA-API header...

#include "MLB_Interface.h"


//---------------------------------------------------------
// 2. Place general module library informations here...

CSG_String Get_Info(int i)
{
	switch( i )
	{
	case MLB_INFO_Name:	default:
		return( _TL("Imagery - ViGrA") );

	case MLB_INFO_Author:
		return( _TL("O. Conrad (c) 2009") );

	case MLB_INFO_Description:
		return( _TW(
			"ViGrA stands for \"Vision with Generic Algorithms\". "
			"It's a novel computer vision library that puts its main "
			"emphasize on customizable algorithms and data structures. "
			"By using template techniques similar to those in the C++ "
			"Standard Template Library, you can easily adapt any VIGRA "
			"component to the needs of your application, without thereby "
			"giving up execution speed.\n"
			"Find out more at the ViGrA - Vision with Generic Algorithms - homepage:\n"
			"<a target=\"_blank\" href=\"http://hci.iwr.uni-heidelberg.de/vigra\">"
			"http://hci.iwr.uni-heidelberg.de</a>"
		));

	case MLB_INFO_Version:
		return( SG_T("1.0") );

	case MLB_INFO_Menu_Path:
		return( _TL("Imagery|ViGrA") );
	}
}


//---------------------------------------------------------
// 3. Include the headers of your modules here...

#include "vigra_smoothing.h"
#include "vigra_edges.h"
#include "vigra_morphology.h"
#include "vigra_distance.h"
#include "vigra_fft.h"
#include "vigra_watershed.h"


//---------------------------------------------------------
// 4. Allow your modules to be created here...

CSG_Module *		Create_Module(int i)
{
	switch( i )
	{
	case  0:	return( new CViGrA_Smoothing );
	case  1:	return( new CViGrA_Edges );
	case  2:	return( new CViGrA_Morphology );
	case  3:	return( new CViGrA_Distance );
	case  4:	return( new CViGrA_Watershed );
	case  5:	return( new CViGrA_FFT );
	case  6:	return( new CViGrA_FFT_Inverse );
	case  7:	return( new CViGrA_FFT_Real );
	case  8:	return( new CViGrA_FFT_Filter );
	}

	return( NULL );
}


///////////////////////////////////////////////////////////
//														 //
//														 //
//														 //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
//{{AFX_SAGA

	MLB_INTERFACE

//}}AFX_SAGA
